// -*- C++ -*-
/*!
 * @file  INPUT_TEST.cpp
 * @brief Data input test
 * @date $Date$
 *
 * $Id$
 */

#include "INPUT_TEST.h"

// Module specification
// <rtc-template block="module_spec">
static const char* input_test_spec[] =
  {
    "implementation_id", "INPUT_TEST",
    "type_name",         "INPUT_TEST",
    "description",       "Data input test",
    "version",           "0.1",
    "vendor",            "Vstone",
    "category",          "Test",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "0",
    "language",          "C++",
    "lang_type",         "compile",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
INPUT_TEST::INPUT_TEST(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_Mt1GainIn("Mt1Gain", m_Mt1Gain),
    m_Mt2GainIn("Mt2Gain", m_Mt2Gain),
    m_Mt1SpdIn("Mt1Spd", m_Mt1Spd),
    m_Mt2SpdIn("Mt2Spd", m_Mt2Spd),
    m_LED1In("LED1", m_LED1),
    m_LED2In("LED2", m_LED2),
    m_BuzPitchIn("BuzPitch", m_BuzPitch),
    m_BuzTimeIn("BuzTime", m_BuzTime),
    m_ModeIn("Mode", m_Mode)

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
INPUT_TEST::~INPUT_TEST()
{
}



RTC::ReturnCode_t INPUT_TEST::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  addInPort("Mt1Gain", m_Mt1GainIn);
  addInPort("Mt2Gain", m_Mt2GainIn);
  addInPort("Mt1Spd", m_Mt1SpdIn);
  addInPort("Mt2Spd", m_Mt2SpdIn);
  addInPort("LED1", m_LED1In);
  addInPort("LED2", m_LED2In);
  addInPort("BuzPitch", m_BuzPitchIn);
  addInPort("BuzTime", m_BuzTimeIn);
  addInPort("Mode", m_ModeIn);
  
  // Set OutPort buffer
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t INPUT_TEST::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_TEST::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_TEST::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_TEST::onActivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_TEST::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t INPUT_TEST::onExecute(RTC::UniqueId ec_id)
{
  //f[^ML^tO
  int send_que=0;

  //ModeM
  if(m_ModeIn.isNew()){ m_ModeIn.read(); send_que++; }

  //[^̃QCM
  if(m_Mt1GainIn.isNew()){ m_Mt1GainIn.read(); send_que++; }
  if(m_Mt2GainIn.isNew()){ m_Mt2GainIn.read(); send_que++; }

  //[^̑xM
  if(m_Mt1SpdIn.isNew()){ m_Mt1SpdIn.read(); send_que++; }
  if(m_Mt2SpdIn.isNew()){ m_Mt2SpdIn.read(); send_que++; }

  //LED̓_ԂM
  if(m_LED1In.isNew()){ m_LED1In.read(); send_que++; }
  if(m_LED2In.isNew()){ m_LED2In.read(); send_que++; }

  //uU[̔ԂƉM
  if(m_BuzTimeIn.isNew()){ m_BuzTimeIn.read(); send_que++; }
  if(m_BuzPitchIn.isNew()){ m_BuzPitchIn.read(); send_que++; }

  //炩̃f[^M
  if(send_que){
    //󂯎lCPU{[h֏
    //2bytȅꍇ́A1byteMBʃoCg珇ԂɑM
    if(CWRC_Connect()){

      CWRC_WriteMemMap(4, (BYTE) m_Mode.data);
      CWRC_WriteMemMap(8, (BYTE) m_Mt1Gain.data);
      CWRC_WriteMemMap(9, (BYTE) m_Mt2Gain.data);
      CWRC_WriteMemMap(14, (BYTE) (m_Mt1Spd.data >> 8));
      CWRC_WriteMemMap(15, (BYTE) m_Mt1Spd.data);
      CWRC_WriteMemMap(16, (BYTE) (m_Mt2Spd.data >> 8));
      CWRC_WriteMemMap(17, (BYTE) m_Mt2Spd.data);
      CWRC_WriteMemMap(42, (BYTE) (m_LED1.data >> 8));
      CWRC_WriteMemMap(43, (BYTE) m_LED1.data);
      CWRC_WriteMemMap(44, (BYTE) (m_LED2.data >> 8));
      CWRC_WriteMemMap(45, (BYTE) m_LED2.data);
      CWRC_WriteMemMap(50, (BYTE) (m_BuzTime.data >> 8));
      CWRC_WriteMemMap(51, (BYTE) m_BuzTime.data);
      CWRC_WriteMemMap(52, (BYTE) (m_BuzPitch.data >> 8));
      CWRC_WriteMemMap(53, (BYTE) m_BuzPitch.data);

	  CWRC_WriteExecute(FALSE);

      CWRC_Disconnect();
    }
  }
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t INPUT_TEST::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_TEST::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_TEST::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_TEST::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t INPUT_TEST::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{
 
  void INPUT_TESTInit(RTC::Manager* manager)
  {
    coil::Properties profile(input_test_spec);
    manager->registerFactory(profile,
                             RTC::Create<INPUT_TEST>,
                             RTC::Delete<INPUT_TEST>);
  }
  
};


